@@ -2,7 +2,7 @@ import threading
 
 from django.core.cache import cache
 
-from smartfields.utils import ProcessingError, VALUE_NOT_SET
+from smartfields.utils import ProcessingError, VALUE_NOT_SET, get_model_name
 
 __all__ = [
     'FieldManager',
@@ -29,12 +29,12 @@ class AsyncHandler(threading.Thread):
         return progress_setter
 
     def run(self):
-        dependencies = list(filter(lambda d: d.async, self.manager.dependencies))
+        dependencies = list(filter(lambda d: d.async_, self.manager.dependencies))
         multiplier = 1.0/len(dependencies)
         try:
             for idx, d in enumerate(dependencies):
                 self.manager._process(
-                    d, self.instance, 
+                    d, self.instance,
                     progress_setter=self.get_progress_setter(multiplier, idx)
                 )
             self.manager.finished_processing(self.instance)
@@ -46,7 +46,7 @@ class AsyncHandler(threading.Thread):
 
 class FieldManager(object):
     _stashed_value = VALUE_NOT_SET
-    
+
     def __init__(self, field, dependencies):
         self.field = field
         self.dependencies = dependencies
@@ -55,7 +55,7 @@ class FieldManager(object):
         for d in self.dependencies:
             d.set_field(self.field)
             if not self.has_async:
-                self.has_async = d.async
+                self.has_async = d.async_
             if not self.should_process:
                 self.should_process = d.should_process()
 
@@ -63,6 +63,11 @@ class FieldManager(object):
     def has_stashed_value(self):
         return self._stashed_value is not VALUE_NOT_SET
 
+    def get_stashed_value(self):
+        if self.has_stashed_value:
+            return self._stashed_value
+        return self.field.get_default()
+
     def stash_previous_value(self, value):
         if not self.has_stashed_value:
             self._stashed_value = value
@@ -93,7 +98,7 @@ class FieldManager(object):
         if self.has_stashed_value:
             self.cleanup_stash()
         self.set_status(instance, {'state': 'complete'})
-        
+
     def cleanup(self, instance):
         for d in self.dependencies:
             d.cleanup(instance)
@@ -102,7 +107,7 @@ class FieldManager(object):
         if hasattr(value, 'delete') and hasattr(value, 'field') \
            and value and not value.field.keep_orphans:
             value.delete(instance_update=False)
-    
+
     def cleanup_stash(self):
         self.delete_value(self._stashed_value)
         self._stashed_value = VALUE_NOT_SET
@@ -139,7 +144,7 @@ class FieldManager(object):
                 d.stash_previous_value(instance, d.get_value(instance))
             try:
                 if self.has_async:
-                    for d in filter(lambda d: not d.async and d.should_process(), 
+                    for d in filter(lambda d: not d.async_ and d.should_process(),
                                     self.dependencies):
                         self._process(d, instance)
                     async_handler = AsyncHandler(self, instance)
@@ -161,13 +166,13 @@ class FieldManager(object):
             if new_value is not VALUE_NOT_SET:
                 value = new_value
         return value
-                
+
 
     def get_status_key(self, instance):
         """Generates a key used to set a status on a field"""
         key_id = "inst_%s" % id(instance) if instance.pk is None else instance.pk
         return "%s.%s-%s-%s" % (instance._meta.app_label,
-                                instance._meta.model_name,
+                                get_model_name(instance),
                                 key_id,
                                 self.field.name)
 
@@ -175,7 +180,7 @@ class FieldManager(object):
         status_key = status_key or self.get_status_key(instance)
         status = {
             'app_label': instance._meta.app_label,
-            'model_name': instance._meta.model_name,
+            'model_name': get_model_name(instance),
             'pk': instance.pk,
             'field_name': self.field.name,
             'state': 'ready'
@@ -209,4 +214,4 @@ class FieldManager(object):
     def contribute_to_model(self, model, name):
         model._smartfields_managers[name] = self
         for d in self.dependencies:
-            d.contribute_to_model(model)
\ No newline at end of file
+            d.contribute_to_model(model)
