@@ -1,11 +1,11 @@
 import subprocess, time
-from django.utils.deconstruct import deconstructible
-from django.utils.six.moves import queue
+from six.moves import queue
 
-from smartfields.utils import NamedTemporaryFile, AsynchronousFileReader, ProcessingError
+from smartfields.utils import NamedTemporaryFile, AsynchronousFileReader, \
+    ProcessingError, deconstructible, get_model_name
 
 __all__ = [
-    'BaseProcessor', 'BaseFileProcessor', 'ExternalFileProcessor'
+    'BaseProcessor', 'BaseFileProcessor', 'RenameFileProcessor', 'ExternalFileProcessor'
 ]
 
 @deconstructible
@@ -16,11 +16,11 @@ class BaseProcessor(object):
     def __init__(self, **kwargs):
         self.default_params = kwargs
 
-    def __call__(self, value, 
-                 instance=None, field=None, field_value=None, dependee=None, **kwargs):
+    def __call__(self, value, instance=None, field=None, dependee=None, 
+                 stashed_value=None, **kwargs):
         return self.process(
-            value, instance=instance, field=field, field_value=field_value, 
-            dependee=dependee, **self.get_params(**kwargs))
+            value, instance=instance, field=field, dependee=dependee, 
+            stashed_value=stashed_value, **self.get_params(**kwargs))
 
     def __eq__(self, other):
         return (type(self) is type(other) and 
@@ -36,12 +36,12 @@ class BaseProcessor(object):
 
     def set_progress(self, progress):
         # see if dependency has set a progress setter, if so use it.
-        try:
-            getattr(self, 'progress_setter')(self, progress)
-        except AttributeError: pass
+        progress_setter = getattr(self, 'progress_setter', None)
+        if callable(progress_setter):
+            progress_setter(self, progress)
 
-    def process(self, value, instance, field, field_value, dependee, **params):
-        raise NotImplementedError("process is a required method")
+    def process(self, value, **kwargs):
+        return value
 
 
 class BaseFileProcessor(BaseProcessor):
@@ -57,6 +57,16 @@ class BaseFileProcessor(BaseProcessor):
         except KeyError: pass
 
 
+class RenameFileProcessor(BaseFileProcessor):
+
+    def process(self, value, stashed_value=None, **kwargs):
+        field_file = stashed_value
+        if not field_file or not field_file._committed:
+            return field_file
+        field_file.file.temporary_file_path = lambda: field_file.path
+        return field_file.file
+
+
 class ExternalFileProcessor(BaseFileProcessor):
 
     cmd_template = None
@@ -88,7 +98,7 @@ class ExternalFileProcessor(BaseFileProcessor):
         need to be deleted, instaed file is safely moved over. With other cloud
         based storage it is a good idea to set `delete=True`."""
         return NamedTemporaryFile(mode='rb', suffix='_%s_%s%s' % (
-            instance._meta.model_name, field.name, self.get_ext()), delete=False)
+            get_model_name(instance), field.name, self.get_ext()), delete=False)
 
     def process(self, in_file, **kwargs):
         out_file = self.get_output_file(in_file, **kwargs)
@@ -123,11 +133,11 @@ class ExternalFileProcessor(BaseFileProcessor):
                       not (stderr_reader is None or stderr_reader.eof()):
                     if stdout_queue is not None:
                         while not stdout_queue.empty():
-                            stdout_args = self.stdout_handler(
+                            stdout_args = self.stdout_handler( # pylint: disable=not-callable
                                 stdout_queue.get(), *stdout_args) or ()
                     if stderr_queue is not None:
                         while not stderr_queue.empty():
-                            stderr_args = self.stderr_handler(
+                            stderr_args = self.stderr_handler( # pylint: disable=not-callable
                                 stderr_queue.get(), *stderr_args) or ()
                     time.sleep(self.sleep_time)
             except ProcessingError:
@@ -145,7 +155,7 @@ class ExternalFileProcessor(BaseFileProcessor):
                     stderr_reader.join()
                     proc.stderr.close()
         if proc.returncode < 0:
-            raise ProcessingError("There was a problem processing this video file")
+            raise ProcessingError("There was a problem processing this file.")
         return out_file
 
 
